@@ -24,7 +24,7 @@
 #'   parameters and timers at the end of execution.  Default value
 #'   "getOption("mlpack.verbose", FALSE)" (logical).
 #'
-#' @return A list with several components:
+#' @return A list with several components defining the class attributes:
 #' \item{output_model}{Output to save trained density estimation tree to
 #'   (DTree).}
 #' \item{tag_counters_file}{The file to output the number of points that
@@ -148,6 +148,8 @@ det <- function(folds=NA,
       "vi" = GetParamMat(p, "vi")
   )
 
+  # Add binding name as class to the output.
+  class(out) <- c("mlpack_det", "mlpack_model_binding", "list")
 
   return(out)
 }
