@@ -14,7 +14,7 @@
 #'   parameters and timers at the end of execution.  Default value
 #'   "getOption("mlpack.verbose", FALSE)" (logical).
 #'
-#' @return A list with several components:
+#' @return A list with several components defining the class attributes:
 #' \item{output}{Output data.  Stored as an edge list (numeric matrix).}
 #'
 #' @details
@@ -88,6 +88,8 @@ emst <- function(input,
       "output" = GetParamMat(p, "output")
   )
 
+  # Add binding name as class to the output.
+  class(out) <- c("mlpack_emst", "mlpack_model_binding", "list")
 
   return(out)
 }
