@@ -38,7 +38,7 @@
 #'   parameters and timers at the end of execution.  Default value
 #'   "getOption("mlpack.verbose", FALSE)" (logical).
 #'
-#' @return A list with several components:
+#' @return A list with several components defining the class attributes:
 #' \item{output_model}{If specified, the KDE model will be saved here
 #'   (KDEModel).}
 #' \item{predictions}{Vector to store density predictions (numeric
@@ -224,6 +224,8 @@ kde <- function(abs_error=NA,
       "predictions" = GetParamCol(p, "predictions")
   )
 
+  # Add binding name as class to the output.
+  class(out) <- c("mlpack_kde", "mlpack_model_binding", "list")
 
   return(out)
 }
