@@ -29,7 +29,7 @@
 #'   parameters and timers at the end of execution.  Default value
 #'   "getOption("mlpack.verbose", FALSE)" (logical).
 #'
-#' @return A list with several components:
+#' @return A list with several components defining the class attributes:
 #' \item{output}{Matrix to save modified dataset to (numeric matrix).}
 #'
 #' @details
@@ -161,6 +161,8 @@ kernel_pca <- function(input,
       "output" = GetParamMat(p, "output")
   )
 
+  # Add binding name as class to the output.
+  class(out) <- c("mlpack_kernel_pca", "mlpack_model_binding", "list")
 
   return(out)
 }
