@@ -42,7 +42,7 @@
 #'   parameters and timers at the end of execution.  Default value
 #'   "getOption("mlpack.verbose", FALSE)" (logical).
 #'
-#' @return A list with several components:
+#' @return A list with several components defining the class attributes:
 #' \item{distances}{Matrix to output distances into (numeric matrix).}
 #' \item{neighbors}{Matrix to output neighbors into (integer matrix).}
 #' \item{output_model}{If specified, the kFN model will be output here
@@ -172,6 +172,8 @@ kfn <- function(algorithm=NA,
       "output_model" = output_model
   )
 
+  # Add binding name as class to the output.
+  class(out) <- c("mlpack_kfn", "mlpack_model_binding", "list")
 
   return(out)
 }
