@@ -39,7 +39,7 @@
 #'   parameters and timers at the end of execution.  Default value
 #'   "getOption("mlpack.verbose", FALSE)" (logical).
 #'
-#' @return A list with several components:
+#' @return A list with several components defining the class attributes:
 #' \item{output_model}{Output for trained linear svm model
 #'   (LinearSVMModel).}
 #' \item{predictions}{If test data is specified, this matrix is where the
@@ -224,6 +224,8 @@ linear_svm <- function(delta=NA,
       "probabilities" = GetParamMat(p, "probabilities")
   )
 
+  # Add binding name as class to the output.
+  class(out) <- c("mlpack_linear_svm", "mlpack_model_binding", "list")
 
   return(out)
 }
