@@ -24,7 +24,7 @@
 #'   parameters and timers at the end of execution.  Default value
 #'   "getOption("mlpack.verbose", FALSE)" (logical).
 #'
-#' @return A list with several components:
+#' @return A list with several components defining the class attributes:
 #' \item{centroid}{If specified, the centroids of each cluster will be
 #'   written to the given matrix (numeric matrix).}
 #' \item{output}{Matrix to write output labels or labeled data to (numeric
@@ -111,6 +111,8 @@ mean_shift <- function(input,
       "output" = GetParamMat(p, "output")
   )
 
+  # Add binding name as class to the output.
+  class(out) <- c("mlpack_mean_shift", "mlpack_model_binding", "list")
 
   return(out)
 }
