@@ -16,7 +16,7 @@
 #'   parameters and timers at the end of execution.  Default value
 #'   "getOption("mlpack.verbose", FALSE)" (logical).
 #'
-#' @return A list with several components:
+#' @return A list with several components defining the class attributes:
 #' \item{output_model}{File to save trained Naive Bayes model to
 #'   (NBCModel).}
 #' \item{predictions}{The matrix in which the predicted labels for the test
@@ -128,6 +128,8 @@ nbc <- function(incremental_variance=FALSE,
       "probabilities" = GetParamMat(p, "probabilities")
   )
 
+  # Add binding name as class to the output.
+  class(out) <- c("mlpack_nbc", "mlpack_model_binding", "list")
 
   return(out)
 }
