@@ -21,7 +21,7 @@
 #'   parameters and timers at the end of execution.  Default value
 #'   "getOption("mlpack.verbose", FALSE)" (logical).
 #'
-#' @return A list with several components:
+#' @return A list with several components defining the class attributes:
 #' \item{h}{Matrix to save the calculated H to (numeric matrix).}
 #' \item{w}{Matrix to save the calculated W to (numeric matrix).}
 #'
@@ -125,6 +125,8 @@ nmf <- function(input,
       "w" = GetParamMat(p, "w")
   )
 
+  # Add binding name as class to the output.
+  class(out) <- c("mlpack_nmf", "mlpack_model_binding", "list")
 
   return(out)
 }
