@@ -21,7 +21,7 @@
 #'   parameters and timers at the end of execution.  Default value
 #'   "getOption("mlpack.verbose", FALSE)" (logical).
 #'
-#' @return A list with several components:
+#' @return A list with several components defining the class attributes:
 #' \item{output}{Matrix to save modified dataset to (numeric matrix).}
 #'
 #' @details
@@ -104,6 +104,8 @@ pca <- function(input,
       "output" = GetParamMat(p, "output")
   )
 
+  # Add binding name as class to the output.
+  class(out) <- c("mlpack_pca", "mlpack_model_binding", "list")
 
   return(out)
 }
