@@ -15,7 +15,7 @@
 #'   parameters and timers at the end of execution.  Default value
 #'   "getOption("mlpack.verbose", FALSE)" (logical).
 #'
-#' @return A list with several components:
+#' @return A list with several components defining the class attributes:
 #' \item{output}{Matrix in which to save the output (numeric matrix).}
 #'
 #' @details
@@ -88,6 +88,8 @@ preprocess_binarize <- function(input,
       "output" = GetParamMat(p, "output")
   )
 
+  # Add binding name as class to the output.
+  class(out) <- c("mlpack_preprocess_binarize", "mlpack_model_binding", "list")
 
   return(out)
 }
