@@ -33,10 +33,10 @@ Octree<DistanceType, StatisticType, MatType>::Octree(const MatType& dataset,
   {
     // Calculate empirical center of data.
     bound |= *this->dataset;
-    arma::vec center;
+    arma::Col<ElemType> center;
     bound.Center(center);
 
-    double maxWidth = 0.0;
+    ElemType maxWidth = 0.0;
     for (size_t i = 0; i < bound.Dim(); ++i)
       if (bound[i].Hi() - bound[i].Lo() > maxWidth)
         maxWidth = bound[i].Hi() - bound[i].Lo();
@@ -75,10 +75,10 @@ Octree<DistanceType, StatisticType, MatType>::Octree(
   {
     // Calculate empirical center of data.
     bound |= *this->dataset;
-    arma::vec center;
+    arma::Col<ElemType> center;
     bound.Center(center);
 
-    double maxWidth = 0.0;
+    ElemType maxWidth = 0.0;
     for (size_t i = 0; i < bound.Dim(); ++i)
       if (bound[i].Hi() - bound[i].Lo() > maxWidth)
         maxWidth = bound[i].Hi() - bound[i].Lo();
@@ -118,10 +118,10 @@ Octree<DistanceType, StatisticType, MatType>::Octree(
   {
     // Calculate empirical center of data.
     bound |= *this->dataset;
-    arma::vec center;
+    arma::Col<ElemType> center;
     bound.Center(center);
 
-    double maxWidth = 0.0;
+    ElemType maxWidth = 0.0;
     for (size_t i = 0; i < bound.Dim(); ++i)
       if (bound[i].Hi() - bound[i].Lo() > maxWidth)
         maxWidth = bound[i].Hi() - bound[i].Lo();
@@ -159,10 +159,10 @@ Octree<DistanceType, StatisticType, MatType>::Octree(MatType&& dataset,
   {
     // Calculate empirical center of data.
     bound |= *this->dataset;
-    arma::vec center;
+    arma::Col<ElemType> center;
     bound.Center(center);
 
-    double maxWidth = 0.0;
+    ElemType maxWidth = 0.0;
     for (size_t i = 0; i < bound.Dim(); ++i)
       if (bound[i].Hi() - bound[i].Lo() > maxWidth)
         maxWidth = bound[i].Hi() - bound[i].Lo();
@@ -201,10 +201,10 @@ Octree<DistanceType, StatisticType, MatType>::Octree(
   {
     // Calculate empirical center of data.
     bound |= *this->dataset;
-    arma::vec center;
+    arma::Col<ElemType> center;
     bound.Center(center);
 
-    double maxWidth = 0.0;
+    ElemType maxWidth = 0.0;
     for (size_t i = 0; i < bound.Dim(); ++i)
       if (bound[i].Hi() - bound[i].Lo() > maxWidth)
         maxWidth = bound[i].Hi() - bound[i].Lo();
@@ -244,10 +244,10 @@ Octree<DistanceType, StatisticType, MatType>::Octree(
   {
     // Calculate empirical center of data.
     bound |= *this->dataset;
-    arma::vec center;
+    arma::Col<ElemType> center;
     bound.Center(center);
 
-    double maxWidth = 0.0;
+    ElemType maxWidth = 0.0;
     for (size_t i = 0; i < bound.Dim(); ++i)
       if (bound[i].Hi() - bound[i].Lo() > maxWidth)
         maxWidth = bound[i].Hi() - bound[i].Lo();
@@ -276,8 +276,8 @@ Octree<DistanceType, StatisticType, MatType>::Octree(
     Octree* parent,
     const size_t begin,
     const size_t count,
-    const arma::vec& center,
-    const double width,
+    const arma::Col<ElemType>& center,
+    const ElemType width,
     const size_t maxLeafSize) :
     begin(begin),
     count(count),
@@ -288,12 +288,17 @@ Octree<DistanceType, StatisticType, MatType>::Octree(
   // Calculate empirical center of data.
   bound |= dataset->cols(begin, begin + count - 1);
 
-  // Now split the node.
-  SplitNode(center, width, maxLeafSize);
+  ElemType maxWidth = 0.0;
+  for (size_t i = 0; i < bound.Dim(); ++i)
+    if (bound[i].Hi() - bound[i].Lo() > maxWidth)
+      maxWidth = bound[i].Hi() - bound[i].Lo();
+
+  if (maxWidth != 0.0)
+    SplitNode(center, width, maxLeafSize);
 
   // Calculate the distance from the empirical center of this node to the
   // empirical center of the parent.
-  arma::vec trueCenter, parentCenter;
+  arma::Col<ElemType> trueCenter, parentCenter;
   bound.Center(trueCenter);
   parent->Bound().Center(parentCenter);
   parentDistance = distance.Evaluate(trueCenter, parentCenter);
@@ -311,8 +316,8 @@ Octree<DistanceType, StatisticType, MatType>::Octree(
     const size_t begin,
     const size_t count,
     std::vector<size_t>& oldFromNew,
-    const arma::vec& center,
-    const double width,
+    const arma::Col<ElemType>& center,
+    const ElemType width,
     const size_t maxLeafSize) :
     begin(begin),
     count(count),
@@ -323,12 +328,17 @@ Octree<DistanceType, StatisticType, MatType>::Octree(
   // Calculate empirical center of data.
   bound |= dataset->cols(begin, begin + count - 1);
 
-  // Now split the node.
-  SplitNode(center, width, oldFromNew, maxLeafSize);
+  ElemType maxWidth = 0.0;
+  for (size_t i = 0; i < bound.Dim(); ++i)
+    if (bound[i].Hi() - bound[i].Lo() > maxWidth)
+      maxWidth = bound[i].Hi() - bound[i].Lo();
+
+  if (maxWidth != 0.0)
+    SplitNode(center, width, oldFromNew, maxLeafSize);
 
   // Calculate the distance from the empirical center of this node to the
   // empirical center of the parent.
-  arma::vec trueCenter, parentCenter;
+  arma::Col<ElemType> trueCenter, parentCenter;
   bound.Center(trueCenter);
   parent->Bound().Center(parentCenter);
   parentDistance = distance.Evaluate(trueCenter, parentCenter);
@@ -378,8 +388,8 @@ operator=(const Octree& other)
     delete children[i];
   children.clear();
 
-  begin = other.Begin();
-  count = other.Count();
+  begin = other.begin;
+  count = other.count;
   bound = other.bound;
   dataset = ((other.parent == NULL) ? new MatType(*other.dataset) : NULL);
   parent = NULL;
@@ -442,8 +452,8 @@ operator=(Octree&& other)
   children.clear();
 
   children = std::move(other.children);
-  begin = other.Begin();
-  count = other.Count();
+  begin = other.begin;
+  count = other.count;
   bound = std::move(other.bound);
   dataset = other.dataset;
   parent = other.Parent();
@@ -460,7 +470,6 @@ operator=(Octree&& other)
   other.count = 0;
   other.dataset = new MatType();
   other.parentDistance = 0.0;
-  other.numDescendants = 0;
   other.furthestDescendantDistance = 0.0;
   other.parent = NULL;
 
@@ -522,7 +531,7 @@ size_t Octree<DistanceType, StatisticType, MatType>::GetNearestChild(
   size_t bestIndex = NumChildren();
   for (size_t i = 0; i < NumChildren(); ++i)
   {
-    const double dist = children[i]->MinDistance(point);
+    const ElemType dist = children[i]->MinDistance(point);
     if (dist < bestDistance)
     {
       bestDistance = dist;
@@ -545,7 +554,7 @@ size_t Octree<DistanceType, StatisticType, MatType>::GetFurthestChild(
   size_t bestIndex = NumChildren();
   for (size_t i = 0; i < NumChildren(); ++i)
   {
-    const double dist = children[i]->MaxDistance(point);
+    const ElemType dist = children[i]->MaxDistance(point);
     if (dist > bestDistance)
     {
       bestDistance = dist;
@@ -566,7 +575,7 @@ size_t Octree<DistanceType, StatisticType, MatType>::GetNearestChild(
   size_t bestIndex = NumChildren();
   for (size_t i = 0; i < NumChildren(); ++i)
   {
-    const double dist = children[i]->MinDistance(queryNode);
+    const ElemType dist = children[i]->MinDistance(queryNode);
     if (dist < bestDistance)
     {
       bestDistance = dist;
@@ -587,7 +596,7 @@ size_t Octree<DistanceType, StatisticType, MatType>::GetFurthestChild(
   size_t bestIndex = NumChildren();
   for (size_t i = 0; i < NumChildren(); ++i)
   {
-    const double dist = children[i]->MaxDistance(queryNode);
+    const ElemType dist = children[i]->MaxDistance(queryNode);
     if (dist > bestDistance)
     {
       bestDistance = dist;
@@ -772,8 +781,8 @@ void Octree<DistanceType, StatisticType, MatType>::serialize(
 //! Split the node.
 template<typename DistanceType, typename StatisticType, typename MatType>
 void Octree<DistanceType, StatisticType, MatType>::SplitNode(
-    const arma::vec& center,
-    const double width,
+    const arma::Col<ElemType>& center,
+    const ElemType width,
     const size_t maxLeafSize)
 {
   // No need to split if we have fewer than the maximum number of points in this
@@ -846,8 +855,8 @@ void Octree<DistanceType, StatisticType, MatType>::SplitNode(
   }
 
   // Now that the dataset is reordered, we can create the children.
-  arma::vec childCenter(center.n_elem);
-  const double childWidth = width / 2.0;
+  arma::Col<ElemType> childCenter(center.n_elem);
+  const ElemType childWidth = width / 2.0;
   for (size_t i = 0; i < childBegins.n_elem - 1; ++i)
   {
     // If the child has no points, don't create it.
@@ -873,8 +882,8 @@ void Octree<DistanceType, StatisticType, MatType>::SplitNode(
 //! Split the node, and store mappings.
 template<typename DistanceType, typename StatisticType, typename MatType>
 void Octree<DistanceType, StatisticType, MatType>::SplitNode(
-    const arma::vec& center,
-    const double width,
+    const arma::Col<ElemType>& center,
+    const ElemType width,
     std::vector<size_t>& oldFromNew,
     const size_t maxLeafSize)
 {
@@ -948,8 +957,8 @@ void Octree<DistanceType, StatisticType, MatType>::SplitNode(
   }
 
   // Now that the dataset is reordered, we can create the children.
-  arma::vec childCenter(center.n_elem);
-  const double childWidth = width / 2.0;
+  arma::Col<ElemType> childCenter(center.n_elem);
+  const ElemType childWidth = width / 2.0;
   for (size_t i = 0; i < childBegins.n_elem - 1; ++i)
   {
     // If the child has no points, don't create it.
